export type Arg<T = any> = {
    /** Argument/property name */
    name: string;
    /** Argument description for help page */
    desc: string;
    /** Available shorthands */
    flags?: string[];
    /** Argument is not required */
    optional?: boolean;
    /** Default value if argument is not used */
    default?: T;
    /** Collects any unmatched arguments */
    extras?: boolean;
};
export declare class ArgParser {
    readonly name: string;
    readonly desc: string;
    readonly argList: (ArgParser | Arg)[];
    readonly examples: string[];
    commands: ArgParser[];
    args: Arg[];
    flags: Arg[];
    defaults: {
        [key: string]: any;
    };
    /**
     * Create a unix-like argument parser to extract flags from the argument list. Can also create help messages.
     *
     * @param {string} name Script name
     * @param {string} desc Help description
     * @param {(ArgParser | Arg[]} argList Array of CLI arguments
     * @param {string[]} examples Additional examples to display
     */
    constructor(name: string, desc: string, argList?: (ArgParser | Arg)[], examples?: string[]);
    /**
     * Parse an array into an arguments dictionary using the configuration.
     *
     * @param {string[]} args Array of arguments to be parsed
     * @returns {object} Dictionary of arguments with defaults applied
     */
    parse(args: string[]): any;
    /**
     * Create help message from the provided description & argument list.
     *
     * @returns {string} Help message
     * @param opts Help options: command - display a commands help, message - override help description
     */
    help(opts?: {
        command?: string;
        message?: string;
    }): string;
}
