/**
 * An array which functions as a set. It guarantees unique elements
 * and provides set functions for comparisons
 */
export declare class ASet<T> extends Array {
    /** Number of elements in set */
    get size(): number;
    /**
     * Array to create set from, duplicate values will be removed
     * @param {T[]} elements Elements which will be added to set
     */
    constructor(elements?: T[]);
    /**
     * Add elements to set if unique
     * @param items
     */
    add(...items: T[]): this;
    /**
     * Delete elements from set
     * @param items Elements that will be deleted
     */
    delete(...items: T[]): this;
    /**
     * Create list of elements this set has which the comparison set does not
     * @param {ASet<T>} set Set to compare against
     * @return {ASet<T>} Different elements
     */
    difference(set: ASet<T>): ASet<T>;
    /**
     * Check if set includes element
     * @param {T} el Element to look for
     * @return {boolean} True if element was found, false otherwise
     */
    has(el: T): boolean;
    /**
     * Find index number of element, or -1 if it doesn't exist. Matches by equality not reference
     *
     * @param {T} search Element to find
     * @param {number} fromIndex Starting index position
     * @return {number} Element index number or -1 if missing
     */
    indexOf(search: T, fromIndex?: number): number;
    /**
     * Create list of elements this set has in common with the comparison set
     * @param {ASet<T>} set Set to compare against
     * @return {boolean} Set of common elements
     */
    intersection(set: ASet<T>): ASet<T>;
    /**
     * Check if this set has no elements in common with the comparison set
     * @param {ASet<T>} set Set to compare against
     * @return {boolean} True if nothing in common, false otherwise
     */
    isDisjointFrom(set: ASet<T>): boolean;
    /**
     * Check if all elements in this set are included in the comparison set
     * @param {ASet<T>} set Set to compare against
     * @return {boolean} True if all elements are included, false otherwise
     */
    isSubsetOf(set: ASet<T>): boolean;
    /**
     * Check if all elements from comparison set are included in this set
     * @param {ASet<T>} set Set to compare against
     * @return {boolean} True if all elements are included, false otherwise
     */
    isSuperset(set: ASet<T>): boolean;
    /**
     * Create list of elements that are only in one set but not both (XOR)
     * @param {ASet<T>} set Set to compare against
     * @return {ASet<T>} New set of unique elements
     */
    symmetricDifference(set: ASet<T>): ASet<any>;
    /**
     * Create joined list of elements included in this & the comparison set
     * @param {ASet<T>} set Set join
     * @return {ASet<T>} New set of both previous sets combined
     */
    union(set: ASet<T> | Array<T>): ASet<any>;
}
