export type TypedListener = (...args: any[]) => any;
export type TypedEvents = {
    [k in string | symbol]: TypedListener;
} & {
    '*': (event: string, ...args: any[]) => any;
};
export type NamespaceEvents<Namespace extends string, Events extends TypedEvents> = {
    [K in keyof Events as `${Namespace}:${Extract<K, string>}`]: Events[K];
};
export declare class TypedEmitter<T extends TypedEvents = TypedEvents> {
    private static listeners;
    private listeners;
    static emit(event: any, ...args: any[]): void;
    static off(event: any, listener: TypedListener): void;
    static on(event: any, listener: TypedListener): () => void;
    static once(event: any, listener?: TypedListener): Promise<any>;
    emit<K extends keyof T>(event: K, ...args: Parameters<T[K]>): void;
    off<K extends keyof T = string>(event: K, listener: T[K]): void;
    on<K extends keyof T = string>(event: K, listener: T[K]): () => void;
    once<K extends keyof T = string>(event: K, listener?: T[K]): Promise<any>;
}
