import { PromiseProgress } from './promise-progress';

/**
 * Download blob as a file
 *
 * @param {Blob} blob File as a blob
 * @param {string} name Name blob will be downloaded as
 */
export declare function downloadFile(blob: Blob | string | string[], name: string): void;
/**
 * Download a file from a URL
 *
 * @param href URL that will be downloaded
 * @param {string} name Override download name
 */
export declare function downloadUrl(href: any, name?: string): void;
/**
 * Open filebrowser & return selected file
 *
 * @param {{accept?: string, multiple?: boolean}} options accept - selectable mimetypes, multiple - Allow selecting more than 1 file
 * @return {Promise<File[]>} Array of selected files
 */
export declare function fileBrowser(options?: {
    accept?: string;
    multiple?: boolean;
}): Promise<File[]>;
/**
 * Extract text from a file
 *
 * @param file File to extract text from
 * @return {Promise<string | null>} File contents
 */
export declare function fileText(file: any): Promise<string | null>;
/**
 * Create timestamp intended for filenames from a date
 *
 * @param {string} name Name of file, `{{TIMESTAMP}}` will be replaced
 * @param {Date | number | string} date Date to use for timestamp
 * @return {string} Interpolated filename, or the raw timestamp if name was omitted
 */
export declare function timestampFilename(name?: string, date?: Date | number | string): string;
/**
 * Upload file to URL with progress callback using PromiseProgress
 *
 * @param {{url: string, files: File[], headers?: {[p: string]: string}, withCredentials?: boolean}} options
 * @return {PromiseProgress<T>} Promise of request with `onProgress` callback
 */
export declare function uploadWithProgress<T>(options: {
    url: string;
    files: File[];
    headers?: {
        [key: string]: string;
    };
    withCredentials?: boolean;
}): PromiseProgress<T>;
