import { PromiseProgress } from './promise-progress';

export type DecodedResponse<T> = Response & {
    data: T | null;
};
export type HttpInterceptor = (response: Response, next: () => void) => void;
export type HttpRequestOptions = {
    body?: any;
    decode?: boolean;
    fragment?: string;
    headers?: {
        [key: string | symbol]: string | null | undefined;
    };
    method?: 'GET' | 'POST' | 'PATCH' | 'PUT' | 'DELETE';
    query?: {
        key: string;
        value: string;
    }[] | {
        [key: string]: string;
    };
    url?: string;
    [key: string]: any;
};
export type HttpDefaults = {
    headers?: {
        [key: string | symbol]: string | null | undefined;
    };
    interceptors?: HttpInterceptor[];
    url?: string;
};
export declare class Http {
    private static interceptors;
    static headers: {
        [key: string]: string | null | undefined;
    };
    private interceptors;
    headers: {
        [key: string]: string | null | undefined;
    };
    url: string | null;
    constructor(defaults?: HttpDefaults);
    static addInterceptor(fn: HttpInterceptor): () => void;
    addInterceptor(fn: HttpInterceptor): () => void;
    request<T>(opts?: HttpRequestOptions): PromiseProgress<DecodedResponse<T>>;
}
