export type ProgressCallback = (progress: number) => any;
/**
 * A promise that fires the `onProgress` callback on incremental progress
 *
 * @example
 * ```js
 * const promise = new Promise((resolve, reject, progress) => {
 *   const max = 10;
 * 	 for(let i = 0; i < max; i++) progress(i / max);
 * 	 resolve(1);
 * });
 *
 * console.log(promise.progress);
 *
 * promise.onProgress(console.log)
 *        .then(console.log)
 *        .catch(console.error)
 *        .finally(...);
 *
 * ```
 */
export declare class PromiseProgress<T> extends Promise<T> {
    private listeners;
    private _progress;
    get progress(): number;
    set progress(p: number);
    constructor(executor: (resolve: (value: T) => any, reject: (reason: any) => void, progress: (progress: number) => any) => void);
    static from<T>(promise: Promise<T>): PromiseProgress<T>;
    private from;
    onProgress(callback: ProgressCallback): this;
    then(res?: (v: T) => any, rej?: (err: any) => any): PromiseProgress<any>;
    catch(rej?: (err: any) => any): PromiseProgress<any>;
    finally(res?: () => any): PromiseProgress<any>;
}
